# legend-pydataobj

[![PyPI](https://img.shields.io/pypi/v/legend-pydataobj?logo=pypi)](https://pypi.org/project/legend-pydataobj/)
![GitHub tag (latest by date)](https://img.shields.io/github/v/tag/legend-exp/legend-pydataobj?logo=git)
[![GitHub Workflow Status](https://img.shields.io/github/checks-status/legend-exp/legend-pydataobj/main?label=main%20branch&logo=github)](https://github.com/legend-exp/legend-pydataobj/actions)
[![pre-commit](https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit&logoColor=white)](https://github.com/pre-commit/pre-commit)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![Codecov](https://img.shields.io/codecov/c/github/legend-exp/legend-pydataobj?logo=codecov)](https://app.codecov.io/gh/legend-exp/legend-pydataobj)
![GitHub issues](https://img.shields.io/github/issues/legend-exp/legend-pydataobj?logo=github)
![GitHub pull requests](https://img.shields.io/github/issues-pr/legend-exp/legend-pydataobj?logo=github)
![License](https://img.shields.io/github/license/legend-exp/legend-pydataobj)
[![Read the Docs](https://img.shields.io/readthedocs/legend-pydataobj?logo=readthedocs)](https://legend-pydataobj.readthedocs.io)
[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.10592107.svg)](https://doi.org/10.5281/zenodo.10592107)

This package provides a Python implementation of the LEGEND Data Objects (LGDO)
and I/O to HDF5, including [Numba](https://numba.pydata.org/)-accelerated custom
compression algorithms for particle detector signals. More documentation is
available in the
[LEGEND data format specification](https://legend-exp.github.io/legend-data-format-specs).

If you are using this software,
[consider citing](https://doi.org/10.5281/zenodo.10592107)!
